==> quick_resto_API-1.0.4.tar.gz: quick_resto_API-1.0.4/quick_resto_API/operations_with_objects/modules/inventory_document_operations.py <==
from quick_resto_API.operations_with_objects.operations_with_objects import OperationsWithObjects
from quick_resto_API.operations_with_objects.system_object import SystemObject
from quick_resto_API.quick_resto_api import QuickRestoApi
from quick_resto_API.quick_resto_objects.modules.warehouse.inventory_document import InventoryDocument

class InventoryDocumentOperations(SystemObject):
    def __init__(self, api: QuickRestoApi):
        self._operations_with_objects = OperationsWithObjects(api)

        self._module_name:str = "warehouse.inventory.document"

    def get_list_of_inventory_document(self, ownerContextId: int = None, ownerContextClassName: str = None,
                           showDeleted: bool = False) -> list:

        json_response = self._operations_with_objects.getList(self._module_name,
                                                              ownerContextId, ownerContextClassName, showDeleted).json()

        result = list()

        for object in json_response:
            result.append(InventoryDocument(**object))

        return result

    def get_tree_of_inventory_document(self, ownerContextId: int = None, ownerContextClassName: str = None,
                           showDeleted: bool = False) -> list:

        json_response = self._operations_with_objects.getTree(self._module_name,
                                                              ownerContextId, ownerContextClassName, showDeleted).json()

        result = list()

        for object in json_response:
            result.append(InventoryDocument(**object))

        return result

    def get_inventory_document(self, objectId: int, objectRid: int = None) -> InventoryDocument:
        json_response = self._operations_with_objects.getObject(self._module_name, objectId, objectRid).json()

        return InventoryDocument(**json_response)

    def get_inventory_document_with_subobjects(self, objectId: int, objectRid: int = None) -> InventoryDocument:
        json_response = self._operations_with_objects.getObjectWithSubobjects(self._module_name, objectId, objectRid).json()

        return InventoryDocument(**json_response)

    def create_inventory_document(self, object: InventoryDocument,ownerContextId: int = None,
                                                ownerContextClassName: str = None, parentContextId: int = None,
                                                parentContextClassName: str = None) -> InventoryDocument:

        json_response = self._operations_with_objects.createObject(object, self._module_name, ownerContextId, 
                                                ownerContextClassName, parentContextId, parentContextClassName).json()

        return InventoryDocument(**json_response)

    def update_inventory_document(self, object: InventoryDocument,ownerContextId: int = None,
                                                ownerContextClassName: str = None, parentContextId: int = None,
                                                parentContextClassName: str = None) -> InventoryDocument:

        json_response = self._operations_with_objects.updateObject(object, self._module_name, ownerContextId, 
                                                ownerContextClassName, parentContextId, parentContextClassName).json()

        return InventoryDocument(**json_response)

    def remove_inventory_document(self, object: InventoryDocument,ownerContextId: int = None,
                                                ownerContextClassName: str = None, parentContextId: int = None,
                                                parentContextClassName: str = None) -> InventoryDocument:

        json_response = self._operations_with_objects.removeObject(object, self._module_name, ownerContextId, 
                                                ownerContextClassName, parentContextId, parentContextClassName).json()

        return InventoryDocument(**json_response)

    def recover_inventory_document(self, object: InventoryDocument,ownerContextId: int = None,
                                                ownerContextClassName: str = None, parentContextId: int = None,
                                                parentContextClassName: str = None) -> InventoryDocument:

        json_response = self._operations_with_objects.recoverObject(object, self._module_name, ownerContextId, 
                                                ownerContextClassName, parentContextId, parentContextClassName).json()

        return InventoryDocument(**json_response)

==> quick_resto_API-1.0.20.tar.gz: quick_resto_API-1.0.20/quick_resto_API/operations_with_objects/modules/inventory_document_operations.py <==
from quick_resto_API.operations_with_objects.operations_with_objects import OperationsWithObjects
from quick_resto_API.operations_with_objects.system_object import SystemObject
from quick_resto_API.quick_resto_api import QuickRestoApi
from quick_resto_API.quick_resto_objects.modules.warehouse.inventory_document import InventoryDocument

class InventoryDocumentOperations(SystemObject):
    def __init__(self, api: QuickRestoApi):
        self._operations_with_objects = OperationsWithObjects(api)

        self._module_name:str = "warehouse.inventory.document"

    def get_list_of_inventory_document(self, ownerContextId: int = None, ownerContextClassName: str = None,
                           showDeleted: bool = False) -> list[InventoryDocument]:

        json_response = self._operations_with_objects.getList(self._module_name,
                                                              ownerContextId, ownerContextClassName, showDeleted).json()

        result:list[InventoryDocument] = list()

        for object in json_response:
            result.append(InventoryDocument(**object))

        return result

    def get_tree_of_inventory_document(self, ownerContextId: int = None, ownerContextClassName: str = None,
                           showDeleted: bool = False) -> list[InventoryDocument]:

        json_response = self._operations_with_objects.getTree(self._module_name,
                                                              ownerContextId, ownerContextClassName, showDeleted).json()

        result:list[InventoryDocument] = list()

        for object in json_response:
            result.append(InventoryDocument(**object))

        return result

    def get_inventory_document(self, objectId: int, objectRid: int = None) -> InventoryDocument:
        json_response = self._operations_with_objects.getObject(self._module_name, objectId, objectRid).json()

        return InventoryDocument(**json_response)

    def get_inventory_document_with_subobjects(self, objectId: int, objectRid: int = None) -> InventoryDocument:
        json_response = self._operations_with_objects.getObjectWithSubobjects(self._module_name, objectId, objectRid).json()

        return InventoryDocument(**json_response)

    def create_inventory_document(self, object: InventoryDocument,ownerContextId: int = None,
                                                ownerContextClassName: str = None, parentContextId: int = None,
                                                parentContextClassName: str = None) -> InventoryDocument:

        json_response = self._operations_with_objects.createObject(object, self._module_name, ownerContextId, 
                                                ownerContextClassName, parentContextId, parentContextClassName).json()

        return InventoryDocument(**json_response)

    def update_inventory_document(self, object: InventoryDocument,ownerContextId: int = None,
                                                ownerContextClassName: str = None, parentContextId: int = None,
                                                parentContextClassName: str = None) -> InventoryDocument:

        json_response = self._operations_with_objects.updateObject(object, self._module_name, ownerContextId, 
                                                ownerContextClassName, parentContextId, parentContextClassName).json()

        return InventoryDocument(**json_response)

    def remove_inventory_document(self, object: InventoryDocument,ownerContextId: int = None,
                                                ownerContextClassName: str = None, parentContextId: int = None,
                                                parentContextClassName: str = None) -> InventoryDocument:

        json_response = self._operations_with_objects.removeObject(object, self._module_name, ownerContextId, 
                                                ownerContextClassName, parentContextId, parentContextClassName).json()

        return InventoryDocument(**json_response)

    def recover_inventory_document(self, object: InventoryDocument,ownerContextId: int = None,
                                                ownerContextClassName: str = None, parentContextId: int = None,
                                                parentContextClassName: str = None) -> InventoryDocument:

        json_response = self._operations_with_objects.recoverObject(object, self._module_name, ownerContextId, 
                                                ownerContextClassName, parentContextId, parentContextClassName).json()

        return InventoryDocument(**json_response)
